==> blesta-3.4.0.zip: blesta/language/en_us/admin_company_gateways.php <==
<?php
/**
 * Language definitions for the Admin Company Gateways settings controller/views
 * 
 * @package blesta
 * @subpackage blesta.language.en_us
 * @copyright Copyright (c) 2010, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

// Success
$lang['AdminCompanyGateways.!success.manage_updated'] = "The gateway was successfully updated.";
$lang['AdminCompanyGateways.!success.upgraded'] = "The gateway was successfully upgraded.";
$lang['AdminCompanyGateways.!success.uninstalled'] = "The gateway was successfully uninstalled.";
$lang['AdminCompanyGateways.!success.installed'] = "The gateway was successfully installed.";


// Available Gateways
$lang['AdminCompanyGateways.available.page_title'] = "Settings > Company > Gateways > Available";
$lang['AdminCompanyGateways.available.boxtitle_gateway'] = "Available Gateways";

$lang['AdminCompanyGateways.available.heading_merchant'] = "Merchant";
$lang['AdminCompanyGateways.available.heading_nonmerchant'] = "Non-Merchant";

$lang['AdminCompanyGateways.available.text_author'] = "Author:";
$lang['AdminCompanyGateways.available.text_author_url'] = "Author URL";
$lang['AdminCompanyGateways.available.signup_url'] = "Signup";
$lang['AdminCompanyGateways.available.text_version'] = "(ver %1\$s)"; // %1$s is the version number of this gateway
$lang['AdminCompanyGateways.available.text_supports'] = "Supports:";
$lang['AdminCompanyGateways.available.text_merchantach'] = "ACH";
$lang['AdminCompanyGateways.available.text_merchantachoffsite'] = "ACH offsite";
$lang['AdminCompanyGateways.available.text_merchantcc'] = "Credit Card";
$lang['AdminCompanyGateways.available.text_merchantccoffsite'] = "Credit Card offsite";
$lang['AdminCompanyGateways.available.text_merchant_none'] = "There are no available merchant gateways.";
$lang['AdminCompanyGateways.available.text_nonmerchant_none'] = "There are no available non-merchant gateways.";

$lang['AdminCompanyGateways.available.btn_install'] = "Install";


// Installed Gateways
$lang['AdminCompanyGateways.installed.page_title'] = "Settings > Company > Gateways > Installed";
$lang['AdminCompanyGateways.installed.boxtitle_gateway'] = "Installed Gateways";

$lang['AdminCompanyGateways.installed.heading_merchant'] = "Merchant";
$lang['AdminCompanyGateways.installed.heading_nonmerchant'] = "Non-Merchant";

$lang['AdminCompanyGateways.installed.text_author'] = "Author:";
$lang['AdminCompanyGateways.installed.text_author_url'] = "Author URL";
$lang['AdminCompanyGateways.installed.signup_url'] = "Signup";
$lang['AdminCompanyGateways.installed.text_version'] = "(ver %1\$s)"; // %1$s is the version number of this gateway
$lang['AdminCompanyGateways.installed.text_supports'] = "Supports:";
$lang['AdminCompanyGateways.installed.text_merchantach'] = "ACH";
$lang['AdminCompanyGateways.installed.text_merchantachoffsite'] = "ACH offsite";
$lang['AdminCompanyGateways.installed.text_merchantcc'] = "Credit Card";
$lang['AdminCompanyGateways.installed.text_merchantccoffsite'] = "Credit Card offsite";
$lang['AdminCompanyGateways.installed.text_merchant_none'] = "There are no installed merchant gateways.";
$lang['AdminCompanyGateways.installed.text_nonmerchant_none'] = "There are no installed non-merchant gateways.";

$lang['AdminCompanyGateways.installed.btn_uninstall'] = "Uninstall";
$lang['AdminCompanyGateways.installed.btn_manage'] = "Manage";
$lang['AdminCompanyGateways.installed.btn_upgrade'] = "Upgrade";

$lang['AdminCompanyGateways.installed.confirm_uninstall'] = "Are you sure you want to uninstall this gateway?";


// Manage Gateways
$lang['AdminCompanyGateways.manage.page_title'] = "Settings > Company > Gateways > Manage %1\$s"; // %1$s is the name of the gateway
$lang['AdminCompanyGateways.manage.boxtitle_manage'] = "Manage %1\$s"; // %1$s is the name of the gateway

$lang['AdminCompanyGateways.manage.heading_gateway'] = "Gateway Options";
$lang['AdminCompanyGateways.manage.heading_currencies'] = "Accepted Currencies";

$lang['AdminCompanyGateways.manage.text_addcurrency'] = "add currency";
$lang['AdminCompanyGateways.manage.text_in_use_by'] = "in use by";

$lang['AdminCompanyGateways.manage.update_settings'] = "Update Settings";
?>

==> blesta-4.0.0.zip: blesta/language/en_us/admin_company_gateways.php <==
<?php
/**
 * Language definitions for the Admin Company Gateways settings controller/views
 *
 * @package blesta
 * @subpackage blesta.language.en_us
 * @copyright Copyright (c) 2010, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

// Success
$lang['AdminCompanyGateways.!success.manage_updated'] = "The gateway was successfully updated.";
$lang['AdminCompanyGateways.!success.upgraded'] = "The gateway was successfully upgraded.";
$lang['AdminCompanyGateways.!success.uninstalled'] = "The gateway was successfully uninstalled.";
$lang['AdminCompanyGateways.!success.installed'] = "The gateway was successfully installed.";


$lang['AdminCompanyGateways.!tab.installed'] = "Installed";
$lang['AdminCompanyGateways.!tab.available'] = "Available";


// Available Gateways
$lang['AdminCompanyGateways.available.page_title'] = "Settings > Company > Gateways > Available";
$lang['AdminCompanyGateways.available.boxtitle_gateway'] = "Gateways";

$lang['AdminCompanyGateways.available.heading_merchant'] = "Merchant";
$lang['AdminCompanyGateways.available.heading_nonmerchant'] = "Non-Merchant";

$lang['AdminCompanyGateways.available.text_author'] = "Author:";
$lang['AdminCompanyGateways.available.text_author_url'] = "Author URL";
$lang['AdminCompanyGateways.available.signup_url'] = "Signup";
$lang['AdminCompanyGateways.available.text_version'] = "(ver %1\$s)"; // %1$s is the version number of this gateway
$lang['AdminCompanyGateways.available.text_supports'] = "Supports:";
$lang['AdminCompanyGateways.available.text_merchantach'] = "ACH";
$lang['AdminCompanyGateways.available.text_merchantachoffsite'] = "ACH offsite";
$lang['AdminCompanyGateways.available.text_merchantcc'] = "Credit Card";
$lang['AdminCompanyGateways.available.text_merchantccoffsite'] = "Credit Card offsite";
$lang['AdminCompanyGateways.available.text_merchant_none'] = "There are no available merchant gateways.";
$lang['AdminCompanyGateways.available.text_nonmerchant_none'] = "There are no available non-merchant gateways.";

$lang['AdminCompanyGateways.available.btn_install'] = "Install";


// Installed Gateways
$lang['AdminCompanyGateways.installed.page_title'] = "Settings > Company > Gateways > Installed";
$lang['AdminCompanyGateways.installed.boxtitle_gateway'] = "Gateways";

$lang['AdminCompanyGateways.installed.heading_merchant'] = "Merchant";
$lang['AdminCompanyGateways.installed.heading_nonmerchant'] = "Non-Merchant";

$lang['AdminCompanyGateways.installed.text_author'] = "Author:";
$lang['AdminCompanyGateways.installed.text_author_url'] = "Author URL";
$lang['AdminCompanyGateways.installed.signup_url'] = "Signup";
$lang['AdminCompanyGateways.installed.text_version'] = "(ver %1\$s)"; // %1$s is the version number of this gateway
$lang['AdminCompanyGateways.installed.text_supports'] = "Supports:";
$lang['AdminCompanyGateways.installed.text_merchantach'] = "ACH";
$lang['AdminCompanyGateways.installed.text_merchantachoffsite'] = "ACH offsite";
$lang['AdminCompanyGateways.installed.text_merchantcc'] = "Credit Card";
$lang['AdminCompanyGateways.installed.text_merchantccoffsite'] = "Credit Card offsite";
$lang['AdminCompanyGateways.installed.text_merchant_none'] = "There are no installed merchant gateways.";
$lang['AdminCompanyGateways.installed.text_nonmerchant_none'] = "There are no installed non-merchant gateways.";

$lang['AdminCompanyGateways.installed.btn_uninstall'] = "Uninstall";
$lang['AdminCompanyGateways.installed.btn_manage'] = "Manage";
$lang['AdminCompanyGateways.installed.btn_upgrade'] = "Upgrade";

$lang['AdminCompanyGateways.installed.confirm_uninstall'] = "Are you sure you want to uninstall this gateway?";


// Manage Gateways
$lang['AdminCompanyGateways.manage.page_title'] = "Settings > Company > Gateways > Manage %1\$s"; // %1$s is the name of the gateway
$lang['AdminCompanyGateways.manage.boxtitle_manage'] = "Manage %1\$s"; // %1$s is the name of the gateway

$lang['AdminCompanyGateways.manage.heading_gateway'] = "Gateway Options";
$lang['AdminCompanyGateways.manage.heading_currencies'] = "Accepted Currencies";

$lang['AdminCompanyGateways.manage.text_addcurrency'] = "add currency";
$lang['AdminCompanyGateways.manage.text_in_use_by'] = "in use by";

$lang['AdminCompanyGateways.manage.update_settings'] = "Update Settings";
